@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2015  Jean-Philippe Lang
+# Copyright (C) 2006-2014  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -45,12 +45,11 @@ class ApplicationController < ActionController::Base
       super
       cookies.delete(autologin_cookie_name)
       self.logged_user = nil
-      set_localization
       render_error :status => 422, :message => "Invalid form authenticity token."
     end
   end
 
-  before_filter :session_expiration, :user_setup, :force_logout_if_password_changed, :check_if_login_required, :check_password_change, :set_localization
+  before_filter :session_expiration, :user_setup, :check_if_login_required, :check_password_change, :set_localization
 
   rescue_from ::Unauthorized, :with => :deny_access
   rescue_from ::ActionView::MissingTemplate, :with => :missing_template
@@ -62,7 +61,6 @@ class ApplicationController < ActionController::Base
   def session_expiration
     if session[:user_id]
       if session_expired? && !try_to_autologin
-        set_localization(User.active.find_by_id(session[:user_id]))
         reset_session
         flash[:error] = l(:error_session_expired)
         redirect_to signin_url
@@ -146,18 +144,6 @@ class ApplicationController < ActionController::Base
     user
   end
 
-  def force_logout_if_password_changed
-    passwd_changed_on = User.current.passwd_changed_on || Time.at(0)
-    # Make sure we force logout only for web browser sessions, not API calls
-    # if the password was changed after the session creation.
-    if session[:user_id] && passwd_changed_on.utc.to_i > session[:ctime].to_i
-      reset_session
-      set_localization
-      flash[:error] = l(:error_session_expired)
-      redirect_to signin_url
-    end
-  end
-
   def autologin_cookie_name
     Redmine::Configuration['autologin_cookie_name'].presence || 'autologin'
   end
@@ -211,10 +197,10 @@ class ApplicationController < ActionController::Base
     end
   end
 
-  def set_localization(user=User.current)
+  def set_localization
     lang = nil
-    if user && user.logged?
-      lang = find_language(user.language)
+    if User.current.logged?
+      lang = find_language(User.current.language)
     end
     if lang.nil? && !Setting.force_default_language_for_anonymous? && request.env['HTTP_ACCEPT_LANGUAGE']
       accept_lang = parse_qvalues(request.env['HTTP_ACCEPT_LANGUAGE']).first
@@ -497,7 +483,7 @@ class ApplicationController < ActionController::Base
   end
 
   def render_feed(items, options={})
-    @items = items || []
+    @items = (items || []).to_a
     @items.sort! {|x,y| y.event_datetime <=> x.event_datetime }
     @items = @items.slice(0, Setting.feeds_limit.to_i)
     @title = options[:title] || Setting.app_title
@@ -637,14 +623,12 @@ class ApplicationController < ActionController::Base
   end
 
   # Renders API response on validation failure
-  # for an object or an array of objects
   def render_validation_errors(objects)
-    messages = Array.wrap(objects).map {|object| object.errors.full_messages}.flatten
-    render_api_errors(messages)
-  end
-
-  def render_api_errors(*messages)
-    @error_messages = messages.flatten
+    if objects.is_a?(Array)
+      @error_messages = objects.map {|object| object.errors.full_messages}.flatten
+    else
+      @error_messages = objects.errors.full_messages
+    end
     render :template => 'common/error_messages.api', :status => :unprocessable_entity, :layout => nil
   end
 
