@@ -22,7 +22,7 @@ module MembersHelper
     scope = Principal.active.sorted.not_member_of(project).like(params[:q])
     principal_count = scope.count
     principal_pages = Redmine::Pagination::Paginator.new principal_count, 100, params['page']
-    principals = scope.offset(principal_pages.offset).limit(principal_pages.per_page).all
+    principals = scope.offset(principal_pages.offset).limit(principal_pages.per_page).to_a
 
     s = content_tag('div', principals_check_box_tags('membership[user_ids][]', principals), :id => 'principals')
 
