@@ -1,7 +1,7 @@
 # encoding: utf-8
 #
 # Redmine - project management software
-# Copyright (C) 2006-2015  Jean-Philippe Lang
+# Copyright (C) 2006-2014  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -97,8 +97,6 @@ module QueriesHelper
       link_to value, issue_path(issue)
     when :subject
       link_to value, issue_path(issue)
-    when :parent
-      value ? (value.visible? ? link_to_issue(value, :subject => false) : "##{value.id}") : ''
     when :description
       issue.description? ? content_tag('div', textilizable(issue, :description), :class => "wiki") : ''
     when :done_ratio
@@ -122,20 +120,14 @@ module QueriesHelper
     end
   end
 
-  def csv_value(column, object, value)
+  def csv_value(column, issue, value)
     format_object(value, false) do |value|
       case value.class.name
       when 'Float'
         sprintf("%.2f", value).gsub('.', l(:general_csv_decimal_separator))
       when 'IssueRelation'
-        other = value.other_issue(object)
-        l(value.label_for(object)) + " ##{other.id}"
-      when 'Issue'
-        if object.is_a?(TimeEntry)
-          "#{value.tracker} ##{value.id}: #{value.subject}"
-        else
-          value.id
-        end
+        other = value.other_issue(issue)
+        l(value.label_for(issue)) + " ##{other.id}"
       else
         value
       end
@@ -151,7 +143,7 @@ module QueriesHelper
       end
     end
 
-    export = FCSV.generate(:col_sep => l(:general_csv_separator)) do |csv|
+    export = CSV.generate(:col_sep => l(:general_csv_separator)) do |csv|
       # csv header fields
       csv << columns.collect {|c| Redmine::CodesetUtil.from_utf8(c.caption.to_s, encoding) }
       # csv lines
