@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2015  Jean-Philippe Lang
+# Copyright (C) 2006-2014  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -20,7 +20,6 @@ class IssueStatus < ActiveRecord::Base
   has_many :workflows, :class_name => 'WorkflowTransition', :foreign_key => "old_status_id"
   acts_as_list
 
-  after_update :handle_is_closed_change
   before_destroy :delete_workflow_rules
   after_save     :update_default
 
@@ -28,6 +27,7 @@ class IssueStatus < ActiveRecord::Base
   validates_uniqueness_of :name
   validates_length_of :name, :maximum => 30
   validates_inclusion_of :default_done_ratio, :in => 0..100, :allow_nil => true
+  attr_protected :id
 
   scope :sorted, lambda { order("#{table_name}.position ASC") }
   scope :named, lambda {|arg| where("LOWER(#{table_name}.name) = LOWER(?)", arg.to_s.strip)}
@@ -80,7 +80,7 @@ class IssueStatus < ActiveRecord::Base
         includes(:new_status).
         where(["role_id IN (:role_ids) AND tracker_id = :tracker_id AND (#{conditions})",
           {:role_ids => roles.collect(&:id), :tracker_id => tracker.id, :true => true, :false => false}
-          ]).all.
+          ]).to_a.
         map(&:new_status).compact.sort
     else
       []
@@ -95,24 +95,6 @@ class IssueStatus < ActiveRecord::Base
 
   private
 
-  # Updates issues closed_on attribute when an existing status is set as closed.
-  def handle_is_closed_change
-    if is_closed_changed? && is_closed == true
-      # First we update issues that have a journal for when the current status was set,
-      # a subselect is used to update all issues with a single query
-      subselect = "SELECT MAX(j.created_on) FROM #{Journal.table_name} j" +
-        " JOIN #{JournalDetail.table_name} d ON d.journal_id = j.id" +
-        " WHERE j.journalized_type = 'Issue' AND j.journalized_id = #{Issue.table_name}.id" +
-        " AND d.property = 'attr' AND d.prop_key = 'status_id' AND d.value = :status_id"
-      Issue.where(:status_id => id, :closed_on => nil).
-        update_all(["closed_on = (#{subselect})", {:status_id => id.to_s}])
-
-      # Then we update issues that don't have a journal which means the
-      # current status was set on creation
-      Issue.where(:status_id => id, :closed_on => nil).update_all("closed_on = created_on")
-    end
-  end
-
   def check_integrity
     raise "Can't delete status" if Issue.where(:status_id => id).any?
   end
