@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2015  Jean-Philippe Lang
+# Copyright (C) 2006-2014  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -25,12 +25,11 @@ class Repository < ActiveRecord::Base
   IDENTIFIER_MAX_LENGTH = 255
 
   belongs_to :project
-  has_many :changesets, :order => "#{Changeset.table_name}.committed_on DESC, #{Changeset.table_name}.id DESC"
+  has_many :changesets, lambda{order("#{Changeset.table_name}.committed_on DESC, #{Changeset.table_name}.id DESC")}
   has_many :filechanges, :class_name => 'Change', :through => :changesets
 
   serialize :extra_info
 
-  before_validation :normalize_identifier
   before_save :check_default
 
   # Raw SQL to delete changesets and changes in the database
@@ -39,12 +38,14 @@ class Repository < ActiveRecord::Base
 
   validates_length_of :password, :maximum => 255, :allow_nil => true
   validates_length_of :identifier, :maximum => IDENTIFIER_MAX_LENGTH, :allow_blank => true
-  validates_uniqueness_of :identifier, :scope => :project_id
+  validates_presence_of :identifier, :unless => Proc.new { |r| r.is_default? || r.set_as_default? }
+  validates_uniqueness_of :identifier, :scope => :project_id, :allow_blank => true
   validates_exclusion_of :identifier, :in => %w(browse show entry raw changes annotate diff statistics graph revisions revision)
   # donwcase letters, digits, dashes, underscores but not digits only
   validates_format_of :identifier, :with => /\A(?!\d+$)[a-z0-9\-_]*\z/, :allow_blank => true
   # Checks if the SCM is enabled when creating a repository
   validate :repo_create_validation, :on => :create
+  attr_protected :id
 
   safe_attributes 'identifier',
     'login',
@@ -264,7 +265,7 @@ class Repository < ActiveRecord::Base
         reorder("#{Changeset.table_name}.committed_on DESC, #{Changeset.table_name}.id DESC").
         limit(limit).
         preload(:user).
-        all
+        to_a
     else
       filechanges.
         where("path = ?", path.with_leading_slash).
@@ -313,7 +314,8 @@ class Repository < ActiveRecord::Base
       return @found_committer_users[committer] if @found_committer_users.has_key?(committer)
 
       user = nil
-      c = changesets.where(:committer => committer).includes(:user).first
+      c = changesets.where(:committer => committer).
+            includes(:user).references(:user).first
       if c && c.user
         user = c.user
       elsif committer.strip =~ /^([^<]+)(<(.*)>)?$/
@@ -405,61 +407,8 @@ class Repository < ActiveRecord::Base
     new_record? && project && Repository.where(:project_id => project.id).empty?
   end
 
-  # Returns a hash with statistics by author in the following form:
-  # {
-  #   "John Smith" => { :commits => 45, :changes => 324 },
-  #   "Bob" => { ... }
-  # }
-  #
-  # Notes:
-  # - this hash honnors the users mapping defined for the repository
-  def stats_by_author
-    commits = Changeset.where("repository_id = ?", id).select("committer, user_id, count(*) as count").group("committer, user_id")
-
-    #TODO: restore ordering ; this line probably never worked
-    #commits.to_a.sort! {|x, y| x.last <=> y.last}
-
-    changes = Change.joins(:changeset).where("#{Changeset.table_name}.repository_id = ?", id).select("committer, user_id, count(*) as count").group("committer, user_id")
-
-    user_ids = changesets.map(&:user_id).compact.uniq
-    authors_names = User.where(:id => user_ids).inject({}) do |memo, user|
-      memo[user.id] = user.to_s
-      memo
-    end
-
-    (commits + changes).inject({}) do |hash, element|
-      mapped_name = element.committer
-      if username = authors_names[element.user_id.to_i]
-        mapped_name = username
-      end
-      hash[mapped_name] ||= { :commits_count => 0, :changes_count => 0 }
-      if element.is_a?(Changeset)
-        hash[mapped_name][:commits_count] += element.count.to_i
-      else
-        hash[mapped_name][:changes_count] += element.count.to_i
-      end
-      hash
-    end
-  end
-
-  # Returns a scope of changesets that come from the same commit as the given changeset
-  # in different repositories that point to the same backend
-  def same_commits_in_scope(scope, changeset)
-    scope = scope.joins(:repository).where(:repositories => {:url => url, :root_url => root_url, :type => type})
-    if changeset.scmid.present?
-      scope = scope.where(:scmid => changeset.scmid)
-    else
-      scope = scope.where(:revision => changeset.revision)
-    end
-    scope
-  end
-
   protected
 
-  def normalize_identifier
-    self.identifier = identifier.to_s.strip
-  end
-
   def check_default
     if !is_default? && set_as_default?
       self.is_default = true
@@ -488,10 +437,10 @@ class Repository < ActiveRecord::Base
     ci = "#{table_name_prefix}changesets_issues#{table_name_suffix}"
     cp = "#{table_name_prefix}changeset_parents#{table_name_suffix}"
 
-    connection.delete("DELETE FROM #{ch} WHERE #{ch}.changeset_id IN (SELECT #{cs}.id FROM #{cs} WHERE #{cs}.repository_id = #{id})")
-    connection.delete("DELETE FROM #{ci} WHERE #{ci}.changeset_id IN (SELECT #{cs}.id FROM #{cs} WHERE #{cs}.repository_id = #{id})")
-    connection.delete("DELETE FROM #{cp} WHERE #{cp}.changeset_id IN (SELECT #{cs}.id FROM #{cs} WHERE #{cs}.repository_id = #{id})")
-    connection.delete("DELETE FROM #{cs} WHERE #{cs}.repository_id = #{id}")
+    self.class.connection.delete("DELETE FROM #{ch} WHERE #{ch}.changeset_id IN (SELECT #{cs}.id FROM #{cs} WHERE #{cs}.repository_id = #{id})")
+    self.class.connection.delete("DELETE FROM #{ci} WHERE #{ci}.changeset_id IN (SELECT #{cs}.id FROM #{cs} WHERE #{cs}.repository_id = #{id})")
+    self.class.connection.delete("DELETE FROM #{cp} WHERE #{cp}.changeset_id IN (SELECT #{cs}.id FROM #{cs} WHERE #{cs}.repository_id = #{id})")
+    self.class.connection.delete("DELETE FROM #{cs} WHERE #{cs}.repository_id = #{id}")
     clear_extra_info_of_changesets
   end
 
