@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2015  Jean-Philippe Lang
+# Copyright (C) 2006-2014  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -79,8 +79,8 @@ class User < Principal
                           :after_remove => Proc.new {|user, group| group.user_removed(user)}
   has_many :changesets, :dependent => :nullify
   has_one :preference, :dependent => :destroy, :class_name => 'UserPreference'
-  has_one :rss_token, :class_name => 'Token', :conditions => "action='feeds'"
-  has_one :api_token, :class_name => 'Token', :conditions => "action='api'"
+  has_one :rss_token, lambda {where "action='feeds'"}, :class_name => 'Token'
+  has_one :api_token, lambda {where "action='api'"}, :class_name => 'Token'
   belongs_to :auth_source
 
   scope :logged, lambda { where("#{User.table_name}.status <> #{STATUS_ANONYMOUS}") }
@@ -105,14 +105,18 @@ class User < Principal
   validates_length_of :firstname, :lastname, :maximum => 30
   validates_format_of :mail, :with => /\A([^@\s]+)@((?:[-a-z0-9]+\.)+[a-z]{2,})\z/i, :allow_blank => true
   validates_length_of :mail, :maximum => MAIL_LENGTH_LIMIT, :allow_nil => true
-  validates_confirmation_of :password, :allow_nil => true
   validates_inclusion_of :mail_notification, :in => MAIL_NOTIFICATION_OPTIONS.collect(&:first), :allow_blank => true
   validate :validate_password_length
+  validate do
+    if password_confirmation && password != password_confirmation
+      errors.add(:password, :confirmation)
+    end
+  end
 
   before_create :set_mail_notification
   before_save   :generate_password_if_needed, :update_hashed_password
   before_destroy :remove_references_before_destroy
-  after_save :update_notified_project_ids, :destroy_tokens
+  after_save :update_notified_project_ids
 
   scope :in_group, lambda {|group|
     group_id = group.is_a?(Group) ? group.id : group.to_i
@@ -151,6 +155,15 @@ class User < Principal
     write_attribute(:mail, arg.to_s.strip)
   end
 
+  def self.find_or_initialize_by_identity_url(url)
+    user = where(:identity_url => url).first
+    unless user
+      user = User.new
+      user.identity_url = url
+    end
+    user
+  end
+
   def identity_url=(url)
     if url.blank?
       write_attribute(:identity_url, '')
@@ -279,7 +292,6 @@ class User < Principal
   def salt_password(clear_password)
     self.salt = User.generate_salt
     self.hashed_password = User.hash_password("#{salt}#{User.hash_password clear_password}")
-    self.passwd_changed_on = Time.now
   end
 
   # Does the backend storage allow this user to change their password?
@@ -354,7 +366,7 @@ class User < Principal
 
   def notified_project_ids=(ids)
     @notified_projects_ids_changed = true
-    @notified_projects_ids = ids.map(&:to_i).uniq.select {|n| n > 0}
+    @notified_projects_ids = ids
   end
 
   # Updates per project notifications (after_save callback)
@@ -474,15 +486,15 @@ class User < Principal
 
   # Return user's roles for project
   def roles_for_project(project)
+    roles = []
     # No role on archived projects
-    return [] if project.nil? || project.archived?
+    return roles if project.nil? || project.archived?
     if membership = membership(project)
-      membership.roles.dup
-    elsif project.is_public?
-      project.override_roles(builtin_role)
+      roles = membership.roles
     else
-      []
+      roles << builtin_role
     end
+    roles
   end
 
   # Return true if the user is a member of project
@@ -494,28 +506,20 @@ class User < Principal
   def projects_by_role
     return @projects_by_role if @projects_by_role
 
-    hash = Hash.new([])
-
-    members = Member.joins(:project).
-      where("#{Project.table_name}.status <> 9").
-      where("#{Member.table_name}.user_id = ? OR (#{Project.table_name}.is_public = ? AND #{Member.table_name}.user_id = ?)", self.id, true, Group.builtin_id(self)).
-      preload(:project, :roles)
-
-    members.reject! {|member| member.user_id != id && project_ids.include?(member.project_id)}
-    members.each do |member|
-      if member.project
-        member.roles.each do |role|
-          hash[role] = [] unless hash.key?(role)
-          hash[role] << member.project
+    @projects_by_role = Hash.new([])
+    memberships.each do |membership|
+      if membership.project
+        membership.roles.each do |role|
+          @projects_by_role[role] = [] unless @projects_by_role.key?(role)
+          @projects_by_role[role] << membership.project
         end
       end
     end
-    
-    hash.each do |role, projects|
+    @projects_by_role.each do |role, projects|
       projects.uniq!
     end
 
-    @projects_by_role = hash
+    @projects_by_role
   end
 
   # Returns true if user is arg or belongs to arg
@@ -558,6 +562,8 @@ class User < Principal
         # Authorize if user is authorized on every element of the array
         context.map {|project| allowed_to?(action, project, options, &block)}.reduce(:&)
       end
+    elsif context
+      raise ArgumentError.new("#allowed_to? context argument must be a Project, an Array of projects or nil")
     elsif options[:global]
       # Admin users are always authorized
       return true if admin?
@@ -576,11 +582,7 @@ class User < Principal
 
   # Is the user allowed to do the specified action on any project?
   # See allowed_to? for the actions and valid options.
-  #
-  # NB: this method is not used anywhere in the core codebase as of
-  # 2.5.2, but it's used by many plugins so if we ever want to remove
-  # it it has to be carefully deprecated for a version or two.
-  def allowed_to_globally?(action, options={}, &block)
+  def allowed_to_globally?(action, options, &block)
     allowed_to?(action, nil, options.reverse_merge(:global => true), &block)
   end
 
@@ -690,37 +692,23 @@ class User < Principal
     end
   end
 
-  # Delete all outstanding password reset tokens on password or email change.
-  # Delete the autologin tokens on password change to prohibit session leakage.
-  # This helps to keep the account secure in case the associated email account
-  # was compromised.
-  def destroy_tokens
-    tokens  = []
-    tokens |= ['recovery', 'autologin'] if hashed_password_changed?
-    tokens |= ['recovery'] if mail_changed?
-
-    if tokens.any?
-      Token.where(:user_id => id, :action => tokens).delete_all
-    end
-  end
-
   # Removes references that are not handled by associations
   # Things that are not deleted are reassociated with the anonymous user
   def remove_references_before_destroy
     return if self.id.nil?
 
     substitute = User.anonymous
-    Attachment.where(['author_id = ?', id]).update_all(['author_id = ?', substitute.id])
+    Attachment.where(['author_id = ?', id]).update_all(['author_id = ?', substitute.id]) 
     Comment.where(['author_id = ?', id]).update_all(['author_id = ?', substitute.id])
     Issue.where(['author_id = ?', id]).update_all(['author_id = ?', substitute.id])
     Issue.where(['assigned_to_id = ?', id]).update_all('assigned_to_id = NULL')
-    Journal.where(['user_id = ?', id]).update_all(['user_id = ?', substitute.id])
+    Journal.where(['user_id = ?', id]).update_all(['user_id = ?', substitute.id]) 
     JournalDetail.
       where(["property = 'attr' AND prop_key = 'assigned_to_id' AND old_value = ?", id.to_s]).
       update_all(['old_value = ?', substitute.id.to_s])
     JournalDetail.
       where(["property = 'attr' AND prop_key = 'assigned_to_id' AND value = ?", id.to_s]).
-      update_all(['value = ?', substitute.id.to_s])
+      update_all(['value = ?', substitute.id.to_s]) 
     Message.where(['author_id = ?', id]).update_all(['author_id = ?', substitute.id])
     News.where(['author_id = ?', id]).update_all(['author_id = ?', substitute.id])
     # Remove private queries and keep public ones
