@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2015  Jean-Philippe Lang
+# Copyright (C) 2006-2014  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -33,11 +33,14 @@ class Version < ActiveRecord::Base
   validates :effective_date, :date => true
   validates_inclusion_of :status, :in => VERSION_STATUSES
   validates_inclusion_of :sharing, :in => VERSION_SHARINGS
+  attr_protected :id
 
   scope :named, lambda {|arg| where("LOWER(#{table_name}.name) = LOWER(?)", arg.to_s.strip)}
   scope :open, lambda { where(:status => 'open') }
   scope :visible, lambda {|*args|
-    includes(:project).where(Project.allowed_to_condition(args.first || User.current, :view_issues))
+    joins(:project).
+    references(:project).
+    where(Project.allowed_to_condition(args.first || User.current, :view_issues))
   }
 
   safe_attributes 'name',
@@ -60,10 +63,6 @@ class Version < ActiveRecord::Base
     project.present? && project.attachments_visible?(*args)
   end
 
-  def attachments_deletable?(usr=User.current)
-    project.present? && project.attachments_deletable?(usr)
-  end
-
   def start_date
     @start_date ||= fixed_issues.minimum('start_date')
   end
@@ -230,11 +229,6 @@ class Version < ActiveRecord::Base
     end
   end
 
-  # Returns true if the version is shared, otherwise false
-  def shared?
-    sharing != 'none'
-  end
-
   private
 
   def load_issue_counts
