@@ -341,7 +341,7 @@ class RedCloth3 < String
     A_HLGN = /(?:(?:<>|<|>|\=|[()]+)+)/
     A_VLGN = /[\-^~]/
     C_CLAS = '(?:\([^")]+\))'
-    C_LNGE = '(?:\[[a-z\-_]+\])'
+    C_LNGE = '(?:\[[^"\[\]]+\])'
     C_STYL = '(?:\{[^"}]+\})'
     S_CSPN = '(?:\\\\\d+)'
     S_RSPN = '(?:/\d+)'
@@ -480,7 +480,7 @@ class RedCloth3 < String
         end
 
         lang = $1 if
-            text.sub!( /\[([a-z\-_]+?)\]/, '' )
+            text.sub!( /\[([^)]+?)\]/, '' )
 
         cls = $1 if
             text.sub!( /\(([^()]+?)\)/, '' )
@@ -529,13 +529,13 @@ class RedCloth3 < String
             fullrow.each_line do |row|
                 ratts, row = pba( $1, 'tr' ), $2 if row =~ /^(#{A}#{C}\. )(.*)/m
                 cells = []
-                # the regexp prevents wiki links with a | from being cut as cells 
-                row.scan(/\|(_?#{S}#{A}#{C}\. ?)?((\[\[[^|\]]*\|[^|\]]*\]\]|[^|])*?)(?=\|)/) do |modifiers, cell|
+                row.split( /(\|)(?![^\[\|]*\]\])/ )[1..-2].each do |cell|
+                    next if cell == '|'
                     ctyp = 'd'
-                    ctyp = 'h' if modifiers && modifiers =~ /^_/
+                    ctyp = 'h' if cell =~ /^_/
 
-                    catts = nil
-                    catts = pba( modifiers, 'td' ) if modifiers
+                    catts = ''
+                    catts, cell = pba( $1, 'td' ), $2 if cell =~ /^(_?#{S}#{A}#{C}\. ?)(.*)/
 
                     catts = shelve( catts ) if catts
                     cells << "\t\t\t<t#{ ctyp }#{ catts }>#{ cell }</t#{ ctyp }>" 
@@ -986,8 +986,8 @@ class RedCloth3 < String
     end
     
     def retrieve( text ) 
-        text.gsub!(/ :redsh#(\d+):/) do
-          @shelf[$1.to_i - 1] || $&
+        @shelf.each_with_index do |r, i|
+            text.gsub!( " :redsh##{ i + 1 }:", r )
         end
     end
 
