@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2015  Jean-Philippe Lang
+# Copyright (C) 2006-2014  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -167,7 +167,7 @@ module Redmine
             where("child.id IN (?)", ids).
             order("#{Project.table_name}.lft ASC").
             uniq.
-            all
+            to_a
         else
           @projects = []
         end
@@ -856,9 +856,6 @@ module Redmine
       end
 
       def pdf_task(params, coords, options={})
-        cell_height_ratio = params[:pdf].get_cell_height_ratio()
-        params[:pdf].set_cell_height_ratio(0.1)
-
         height = options[:height] || 2
         # Renders the task bar, with progress and late
         if coords[:bar_start] && coords[:bar_end]
@@ -899,8 +896,6 @@ module Redmine
           params[:pdf].SetX(params[:subject_width] + (coords[:bar_end] || 0) + 5)
           params[:pdf].RDMCell(30, 2, options[:label])
         end
-
-        params[:pdf].set_cell_height_ratio(cell_height_ratio)
       end
 
       def image_task(params, coords, options={})
