@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2015  Jean-Philippe Lang
+# Copyright (C) 2006-2014  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -90,25 +90,10 @@ module Redmine
     # Returns an array of languages names and code sorted by names, example:
     # [["Deutsch", "de"], ["English", "en"] ...]
     #
-    # The result is cached to prevent from loading all translations files
-    # unless :cache => false option is given
-    def languages_options(options={})
-      options = if options[:cache] == false
-        valid_languages.
-          select {|locale| ::I18n.exists?(:general_lang_name, locale)}.
-          map {|lang| [ll(lang.to_s, :general_lang_name), lang.to_s]}.
-          sort {|x,y| x.first <=> y.first }
-      else
-        ActionController::Base.cache_store.fetch "i18n/languages_options" do
-          languages_options :cache => false
-        end
-      end
-      options.map do |name, lang|
-        n = name
-        l = lang
-        n.force_encoding("UTF-8") if n.respond_to?(:force_encoding)
-        l.force_encoding("UTF-8") if l.respond_to?(:force_encoding)
-        [n, l]
+    # The result is cached to prevent from loading all translations files.
+    def languages_options
+      ActionController::Base.cache_store.fetch "i18n/languages_options" do
+        valid_languages.map {|lang| [ll(lang.to_s, :general_lang_name), lang.to_s]}.sort {|x,y| x.first <=> y.first }
       end
     end
 
