@@ -3,14 +3,14 @@ require 'rexml/document'
 module Redmine
   module VERSION #:nodoc:
     MAJOR = 2
-    MINOR = 6
-    TINY  = 4
+    MINOR = 5
+    TINY  = 2
 
     # Branch values:
     # * official release: nil
     # * stable branch:    stable
     # * trunk:            devel
-    BRANCH = 'stable'
+    BRANCH = 'devel'
 
     # Retrieves the revision from the working copy
     def self.revision
