@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2015  Jean-Philippe Lang
+# Copyright (C) 2006-2014  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -127,11 +127,13 @@ class ActivitiesControllerTest < ActionController::TestCase
   end
 
   def test_index_atom_feed_with_one_item_type
-    get :index, :format => 'atom', :show_issues => '1'
-    assert_response :success
-    assert_template 'common/feed'
-
-    assert_select 'title', :text => /Issues/
+    with_settings :default_language => 'en' do
+      get :index, :format => 'atom', :show_issues => '1'
+      assert_response :success
+      assert_template 'common/feed'
+  
+      assert_select 'title', :text => /Issues/
+    end
   end
 
   def test_index_should_show_private_notes_with_permission_only
