@@ -18,8 +18,10 @@
 require File.expand_path('../../test_helper', __FILE__)
 
 class ProjectsControllerTest < ActionController::TestCase
-  fixtures :projects, :versions, :users, :roles, :members, :member_roles, :issues, :journals, :journal_details,
-           :trackers, :projects_trackers, :issue_statuses, :enabled_modules, :enumerations, :boards, :messages,
+  fixtures :projects, :versions, :users, :roles, :members,
+           :member_roles, :issues, :journals, :journal_details,
+           :trackers, :projects_trackers, :issue_statuses,
+           :enabled_modules, :enumerations, :boards, :messages,
            :attachments, :custom_fields, :custom_values, :time_entries
 
   def setup
@@ -420,7 +422,7 @@ class ProjectsControllerTest < ActionController::TestCase
     post :update, :id => 1, :project => {:name => ''}
     assert_response :success
     assert_template 'settings'
-    assert_error_tag :content => /name can&#x27;t be blank/i
+    assert_error_tag :content => /name #{ESCAPED_CANT} be blank/i
   end
 
   def test_update_should_be_denied_for_member_on_closed_project
