@@ -21,6 +21,7 @@ class SearchControllerTest < ActionController::TestCase
   fixtures :projects, :enabled_modules, :roles, :users, :members, :member_roles,
            :issues, :trackers, :issue_statuses, :enumerations,
            :custom_fields, :custom_values,
+           :custom_fields_projects, :custom_fields_trackers,
            :repositories, :changesets
 
   def setup
@@ -39,7 +40,9 @@ class SearchControllerTest < ActionController::TestCase
   end
 
   def test_search_all_projects
-    get :index, :q => 'recipe subproject commit', :all_words => ''
+    with_settings :default_language => 'en' do
+      get :index, :q => 'recipe subproject commit', :all_words => ''
+    end
     assert_response :success
     assert_template 'index'
 
