@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2015  Jean-Philippe Lang
+# Copyright (C) 2006-2014  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 require File.expand_path('../../../test_helper', __FILE__)
 
-class RoutingTimelogsTest < ActionController::IntegrationTest
+class RoutingTimelogsTest < ActionDispatch::IntegrationTest
   def test_timelogs_global
     assert_routing(
         { :method => 'get', :path => "/time_entries" },
@@ -134,6 +134,57 @@ class RoutingTimelogsTest < ActionController::IntegrationTest
       )
   end
 
+  def test_timelogs_scoped_under_project_and_issues
+    assert_routing(
+        { :method => 'get',
+          :path => "/projects/ecookbook/issues/234/time_entries" },
+        { :controller => 'timelog', :action => 'index',
+          :issue_id => '234', :project_id => 'ecookbook' }
+      )
+    assert_routing(
+        { :method => 'get',
+          :path => "/projects/ecookbook/issues/234/time_entries.csv" },
+        { :controller => 'timelog', :action => 'index',
+          :issue_id => '234', :project_id => 'ecookbook', :format => 'csv' }
+      )
+    assert_routing(
+        { :method => 'get',
+          :path => "/projects/ecookbook/issues/234/time_entries.atom" },
+        { :controller => 'timelog', :action => 'index',
+          :issue_id => '234', :project_id => 'ecookbook', :format => 'atom' }
+      )
+    assert_routing(
+        { :method => 'get',
+          :path => "/projects/ecookbook/issues/234/time_entries/new" },
+        { :controller => 'timelog', :action => 'new',
+          :issue_id => '234', :project_id => 'ecookbook' }
+      )
+    assert_routing(
+        { :method => 'get',
+          :path => "/projects/ecookbook/issues/234/time_entries/22/edit" },
+        { :controller => 'timelog', :action => 'edit', :id => '22',
+          :issue_id => '234', :project_id => 'ecookbook' }
+      )
+    assert_routing(
+        { :method => 'post',
+          :path => "/projects/ecookbook/issues/234/time_entries" },
+        { :controller => 'timelog', :action => 'create',
+          :issue_id => '234', :project_id => 'ecookbook' }
+      )
+    assert_routing(
+        { :method => 'put',
+          :path => "/projects/ecookbook/issues/234/time_entries/22" },
+        { :controller => 'timelog', :action => 'update', :id => '22',
+          :issue_id => '234', :project_id => 'ecookbook' }
+      )
+    assert_routing(
+        { :method => 'delete',
+          :path => "/projects/ecookbook/issues/234/time_entries/55" },
+        { :controller => 'timelog', :action => 'destroy', :id => '55',
+          :issue_id => '234', :project_id => 'ecookbook' }
+      )
+  end
+
   def test_timelogs_report
     assert_routing(
         { :method => 'get',
