@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2015  Jean-Philippe Lang
+# Copyright (C) 2006-2014  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -25,18 +25,27 @@ require File.expand_path(File.dirname(__FILE__) + '/object_helpers')
 include ObjectHelpers
 
 require 'awesome_nested_set/version'
+require 'shoulda'
+
+class ActionView::TestCase
+  helper :application
+  include ApplicationHelper
+end
 
 class ActiveSupport::TestCase
   include ActionDispatch::TestProcess
+  include Shoulda::Context::Assertions
+  include Shoulda::Context::InstanceMethods
+  extend Shoulda::Context::ClassMethods
 
   self.use_transactional_fixtures = true
   self.use_instantiated_fixtures  = false
 
-  ESCAPED_CANT  = 'can&#x27;t'
-  ESCAPED_UCANT = 'Can&#x27;t'
+  #ESCAPED_CANT  = 'can&#x27;t'
+  #ESCAPED_UCANT = 'Can&#x27;t'
   # Rails 4.0.2
-  #ESCAPED_CANT  = 'can&#39;t'
-  #ESCAPED_UCANT = 'Can&#39;t'
+  ESCAPED_CANT  = 'can&#39;t'
+  ESCAPED_UCANT = 'Can&#39;t'
 
   def log_user(login, password)
     User.anonymous
