@@ -1,7 +1,7 @@
 # encoding: utf-8
 #
 # Redmine - project management software
-# Copyright (C) 2006-2015  Jean-Philippe Lang
+# Copyright (C) 2006-2014  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -162,30 +162,6 @@ class ChangesetTest < ActiveSupport::TestCase
     assert_equal [1,2,3], c.issue_ids.sort
   end
 
-  def test_update_keywords_with_changes_should_create_journal
-    issue = Issue.generate!(:project_id => 1, :status_id => 1)
-
-    with_settings :commit_update_keywords => [{'keywords' => 'fixes', 'status_id' => '3'}] do
-      assert_difference 'Journal.count' do
-        c = Changeset.generate!(:repository => Project.find(1).repository,:comments => "Fixes ##{issue.id}")
-        assert_include c.id, issue.reload.changeset_ids
-        journal = Journal.order('id DESC').first
-        assert_equal 1, journal.details.count
-      end
-    end
-  end
-
-  def test_update_keywords_without_change_should_not_create_journal
-    issue = Issue.generate!(:project_id => 1, :status_id => 3)
-
-    with_settings :commit_update_keywords => [{'keywords' => 'fixes', 'status_id' => '3'}] do
-      assert_no_difference 'Journal.count' do
-        c = Changeset.generate!(:repository => Project.find(1).repository,:comments => "Fixes ##{issue.id}")
-        assert_include c.id, issue.reload.changeset_ids
-      end
-    end
-  end
-
   def test_update_keywords_with_multiple_rules
     with_settings :commit_update_keywords => [
       {'keywords' => 'fixes, closes', 'status_id' => '5'},
@@ -321,17 +297,6 @@ class ChangesetTest < ActiveSupport::TestCase
     assert_equal 0, issue.done_ratio
   end
 
-  def test_2_repositories_with_same_backend_should_not_link_issue_multiple_times
-    Setting.commit_ref_keywords = '*'
-    r1 = Repository::Subversion.create!(:project_id => 1, :identifier => 'svn1', :url => 'file:///svn1')
-    r2 = Repository::Subversion.create!(:project_id => 1, :identifier => 'svn2', :url => 'file:///svn1')
-    now = Time.now
-    assert_difference 'Issue.find(1).changesets.count' do
-      c1 = Changeset.create!(:repository => r1, :committed_on => now, :comments => 'Fixes #1', :revision => '12345')
-      c1 = Changeset.create!(:repository => r2, :committed_on => now, :comments => 'Fixes #1', :revision => '12345')
-    end
-  end
-
   def test_text_tag_revision
     c = Changeset.new(:revision => '520')
     assert_equal 'r520', c.text_tag
@@ -412,8 +377,7 @@ class ChangesetTest < ActiveSupport::TestCase
   def test_comments_should_be_converted_to_utf8
     proj = Project.find(3)
     # str = File.read("#{RAILS_ROOT}/test/fixtures/encoding/iso-8859-1.txt")
-    str = "Texte encod\xe9 en ISO-8859-1."
-    str.force_encoding("ASCII-8BIT") if str.respond_to?(:force_encoding)
+    str = "Texte encod\xe9 en ISO-8859-1.".force_encoding("ASCII-8BIT")
     r = Repository::Bazaar.create!(
             :project      => proj,
             :url          => '/tmp/test/bazaar',
@@ -425,18 +389,15 @@ class ChangesetTest < ActiveSupport::TestCase
                       :scmid        => '12345',
                       :comments     => str)
     assert( c.save )
-    str_utf8 = "Texte encod\xc3\xa9 en ISO-8859-1."
-    str_utf8.force_encoding("UTF-8") if str_utf8.respond_to?(:force_encoding)
+    str_utf8 = "Texte encod\xc3\xa9 en ISO-8859-1.".force_encoding("UTF-8")
     assert_equal str_utf8, c.comments
   end
 
   def test_invalid_utf8_sequences_in_comments_should_be_replaced_latin1
     proj = Project.find(3)
     # str = File.read("#{RAILS_ROOT}/test/fixtures/encoding/iso-8859-1.txt")
-    str1 = "Texte encod\xe9 en ISO-8859-1."
-    str2 = "\xe9a\xe9b\xe9c\xe9d\xe9e test"
-    str1.force_encoding("UTF-8") if str1.respond_to?(:force_encoding)
-    str2.force_encoding("ASCII-8BIT") if str2.respond_to?(:force_encoding)
+    str1 = "Texte encod\xe9 en ISO-8859-1.".force_encoding("UTF-8")
+    str2 = "\xe9a\xe9b\xe9c\xe9d\xe9e test".force_encoding("ASCII-8BIT")
     r = Repository::Bazaar.create!(
             :project      => proj,
             :url          => '/tmp/test/bazaar',
@@ -455,10 +416,7 @@ class ChangesetTest < ActiveSupport::TestCase
 
   def test_invalid_utf8_sequences_in_comments_should_be_replaced_ja_jis
     proj = Project.find(3)
-    str = "test\xb5\xfetest\xb5\xfe"
-    if str.respond_to?(:force_encoding)
-      str.force_encoding('ASCII-8BIT')
-    end
+    str = "test\xb5\xfetest\xb5\xfe".force_encoding('ASCII-8BIT')
     r = Repository::Bazaar.create!(
             :project      => proj,
             :url          => '/tmp/test/bazaar',
@@ -477,14 +435,12 @@ class ChangesetTest < ActiveSupport::TestCase
     s1 = "\xC2\x80"
     s2 = "\xc3\x82\xc2\x80"
     s4 = s2.dup
-    if s1.respond_to?(:force_encoding)
-      s3 = s1.dup
-      s1.force_encoding('ASCII-8BIT')
-      s2.force_encoding('ASCII-8BIT')
-      s3.force_encoding('ISO-8859-1')
-      s4.force_encoding('UTF-8')
-      assert_equal s3.encode('UTF-8'), s4
-    end
+    s3 = s1.dup
+    s1.force_encoding('ASCII-8BIT')
+    s2.force_encoding('ASCII-8BIT')
+    s3.force_encoding('ISO-8859-1')
+    s4.force_encoding('UTF-8')
+    assert_equal s3.encode('UTF-8'), s4
     proj = Project.find(3)
     r = Repository::Bazaar.create!(
             :project      => proj,
@@ -502,10 +458,8 @@ class ChangesetTest < ActiveSupport::TestCase
 
   def test_invalid_utf8_sequences_in_paths_should_be_replaced
     proj = Project.find(3)
-    str1 = "Texte encod\xe9 en ISO-8859-1"
-    str2 = "\xe9a\xe9b\xe9c\xe9d\xe9e test"
-    str1.force_encoding("UTF-8")      if str1.respond_to?(:force_encoding)
-    str2.force_encoding("ASCII-8BIT") if str2.respond_to?(:force_encoding)
+    str1 = "Texte encod\xe9 en ISO-8859-1".force_encoding("UTF-8")
+    str2 = "\xe9a\xe9b\xe9c\xe9d\xe9e test".force_encoding("ASCII-8BIT")
     r = Repository::Bazaar.create!(
             :project => proj,
             :url => '/tmp/test/bazaar',
@@ -545,9 +499,7 @@ class ChangesetTest < ActiveSupport::TestCase
     assert( c.save )
     assert_equal "", c.comments
     assert_equal nil, c.committer
-    if c.comments.respond_to?(:force_encoding)
-      assert_equal "UTF-8", c.comments.encoding.to_s
-    end
+    assert_equal "UTF-8", c.comments.encoding.to_s
   end
 
   def test_comments_empty
@@ -566,10 +518,8 @@ class ChangesetTest < ActiveSupport::TestCase
     assert( c.save )
     assert_equal "", c.comments
     assert_equal "", c.committer
-    if c.comments.respond_to?(:force_encoding)
-      assert_equal "UTF-8", c.comments.encoding.to_s
-      assert_equal "UTF-8", c.committer.encoding.to_s
-    end
+    assert_equal "UTF-8", c.comments.encoding.to_s
+    assert_equal "UTF-8", c.committer.encoding.to_s
   end
 
   def test_comments_should_accept_more_than_64k
