@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2015  Jean-Philippe Lang
+# Copyright (C) 2006-2014  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -52,8 +52,7 @@ class GroupTest < ActiveSupport::TestCase
 
   def test_blank_name_error_message_fr
     set_language_if_valid 'fr'
-    str = "Nom doit \xc3\xaatre renseign\xc3\xa9(e)"
-    str.force_encoding('UTF-8') if str.respond_to?(:force_encoding)
+    str = "Nom doit \xc3\xaatre renseign\xc3\xa9(e)".force_encoding('UTF-8')
     g = Group.new
     assert !g.save
     assert_include str, g.errors.full_messages
@@ -125,7 +124,7 @@ class GroupTest < ActiveSupport::TestCase
   end
 
   def test_destroy_should_unassign_issues
-    group = Group.find(10)
+    group = Group.first
     Issue.where(:id => 1).update_all(["assigned_to_id = ?", group.id])
 
     assert group.destroy
@@ -133,20 +132,4 @@ class GroupTest < ActiveSupport::TestCase
 
     assert_equal nil, Issue.find(1).assigned_to_id
   end
-
-  def test_builtin_id_with_anonymous_user_should_return_anonymous_group
-    assert_equal 13, Group.builtin_id(User.anonymous)
-  end
-
-  def test_builtin_id_with_anonymous_role_should_return_anonymous_group
-    assert_equal 13, Group.builtin_id(Role.anonymous)
-  end
-
-  def test_builtin_id_with_user_should_return_non_member_group
-    assert_equal 12, Group.builtin_id(User.find(1))
-  end
-
-  def test_builtin_id_with_non_member_role_should_return_non_member_group
-    assert_equal 12, Group.builtin_id(Role.non_member)
-  end
 end
