@@ -21,14 +21,9 @@ class Redmine::CodesetUtilTest < ActiveSupport::TestCase
 
   def test_to_utf8_by_setting_from_latin1
     with_settings :repositories_encodings => 'UTF-8,ISO-8859-1' do
-      s1 = "Texte encod\xc3\xa9"
-      s2 = "Texte encod\xe9"
-      s3 = s2.dup
-      if s1.respond_to?(:force_encoding)
-        s1.force_encoding("UTF-8")
-        s2.force_encoding("ASCII-8BIT")
-        s3.force_encoding("UTF-8")
-      end
+      s1 = "Texte encod\xc3\xa9".force_encoding("UTF-8")
+      s2 = "Texte encod\xe9".force_encoding("ASCII-8BIT")
+      s3 = s2.dup.force_encoding("UTF-8")
       assert_equal s1, Redmine::CodesetUtil.to_utf8_by_setting(s2)
       assert_equal s1, Redmine::CodesetUtil.to_utf8_by_setting(s3)
     end
@@ -36,14 +31,9 @@ class Redmine::CodesetUtilTest < ActiveSupport::TestCase
 
   def test_to_utf8_by_setting_from_euc_jp
     with_settings :repositories_encodings => 'UTF-8,EUC-JP' do
-      s1 = "\xe3\x83\xac\xe3\x83\x83\xe3\x83\x89\xe3\x83\x9e\xe3\x82\xa4\xe3\x83\xb3"
-      s2 = "\xa5\xec\xa5\xc3\xa5\xc9\xa5\xde\xa5\xa4\xa5\xf3"
-      s3 = s2.dup
-      if s1.respond_to?(:force_encoding)
-        s1.force_encoding("UTF-8")
-        s2.force_encoding("ASCII-8BIT")
-        s3.force_encoding("UTF-8")
-      end
+      s1 = "\xe3\x83\xac\xe3\x83\x83\xe3\x83\x89\xe3\x83\x9e\xe3\x82\xa4\xe3\x83\xb3".force_encoding("UTF-8")
+      s2 = "\xa5\xec\xa5\xc3\xa5\xc9\xa5\xde\xa5\xa4\xa5\xf3".force_encoding("ASCII-8BIT")
+      s3 = s2.dup.force_encoding("UTF-8")
       assert_equal s1, Redmine::CodesetUtil.to_utf8_by_setting(s2)
       assert_equal s1, Redmine::CodesetUtil.to_utf8_by_setting(s3)
     end
@@ -51,14 +41,9 @@ class Redmine::CodesetUtilTest < ActiveSupport::TestCase
 
   def test_to_utf8_by_setting_should_be_converted_all_latin1
     with_settings :repositories_encodings => 'ISO-8859-1' do
-      s1 = "\xc3\x82\xc2\x80"
-      s2 = "\xC2\x80"
-      s3 = s2.dup
-      if s1.respond_to?(:force_encoding)
-        s1.force_encoding("UTF-8")
-        s2.force_encoding("ASCII-8BIT")
-        s3.force_encoding("UTF-8")
-      end
+      s1 = "\xc3\x82\xc2\x80".force_encoding("UTF-8")
+      s2 = "\xC2\x80".force_encoding("ASCII-8BIT")
+      s3 = s2.dup.force_encoding("UTF-8")
       assert_equal s1, Redmine::CodesetUtil.to_utf8_by_setting(s2)
       assert_equal s1, Redmine::CodesetUtil.to_utf8_by_setting(s3)
     end
@@ -70,45 +55,33 @@ class Redmine::CodesetUtilTest < ActiveSupport::TestCase
   end
 
   def test_to_utf8_by_setting_returns_ascii_as_utf8
-    s1 = "ASCII"
-    s2 = s1.dup
-    if s1.respond_to?(:force_encoding)
-      s1.force_encoding("UTF-8")
-      s2.force_encoding("ISO-8859-1")
-    end
+    s1 = "ASCII".force_encoding("UTF-8")
+    s2 = s1.dup.force_encoding("ISO-8859-1")
     str1 = Redmine::CodesetUtil.to_utf8_by_setting(s1)
     str2 = Redmine::CodesetUtil.to_utf8_by_setting(s2)
     assert_equal s1, str1
     assert_equal s1, str2
-    if s1.respond_to?(:force_encoding)
-      assert_equal "UTF-8", str1.encoding.to_s
-      assert_equal "UTF-8", str2.encoding.to_s
-    end
+    assert_equal "UTF-8", str1.encoding.to_s
+    assert_equal "UTF-8", str2.encoding.to_s
   end
 
   def test_to_utf8_by_setting_invalid_utf8_sequences_should_be_stripped
     with_settings :repositories_encodings => '' do
       # s1 = File.read("#{RAILS_ROOT}/test/fixtures/encoding/iso-8859-1.txt")
-      s1 = "Texte encod\xe9 en ISO-8859-1."
-      s1.force_encoding("ASCII-8BIT") if s1.respond_to?(:force_encoding)
+      s1 = "Texte encod\xe9 en ISO-8859-1.".force_encoding("ASCII-8BIT")
       str = Redmine::CodesetUtil.to_utf8_by_setting(s1)
-      if str.respond_to?(:force_encoding)
-        assert str.valid_encoding?
-        assert_equal "UTF-8", str.encoding.to_s
-      end
+      assert str.valid_encoding?
+      assert_equal "UTF-8", str.encoding.to_s
       assert_equal "Texte encod? en ISO-8859-1.", str
     end
   end
 
   def test_to_utf8_by_setting_invalid_utf8_sequences_should_be_stripped_ja_jis
     with_settings :repositories_encodings => 'ISO-2022-JP' do
-      s1 = "test\xb5\xfetest\xb5\xfe"
-      s1.force_encoding("ASCII-8BIT") if s1.respond_to?(:force_encoding)
+      s1 = "test\xb5\xfetest\xb5\xfe".force_encoding("ASCII-8BIT")
       str = Redmine::CodesetUtil.to_utf8_by_setting(s1)
-      if str.respond_to?(:force_encoding)
-        assert str.valid_encoding?
-        assert_equal "UTF-8", str.encoding.to_s
-      end
+      assert str.valid_encoding?
+      assert_equal "UTF-8", str.encoding.to_s
       assert_equal "test??test??", str
     end
   end
