@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2015  Jean-Philippe Lang
+# Copyright (C) 2006-2014  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -79,9 +79,8 @@ class MemberTest < ActiveSupport::TestCase
     member = Member.new(:project_id => 1, :user_id => user.id, :role_ids => [])
     assert !member.save
     assert_include I18n.translate('activerecord.errors.messages.empty'), member.errors[:role]
-    str = "R\xc3\xb4le doit \xc3\xaatre renseign\xc3\xa9(e)"
-    str.force_encoding('UTF-8') if str.respond_to?(:force_encoding)
-    assert_equal str, [member.errors.full_messages].flatten.join
+    assert_equal "R\xc3\xb4le doit \xc3\xaatre renseign\xc3\xa9(e)".force_encoding('UTF-8'),
+    	[member.errors.full_messages].flatten.join
   end
 
   def test_validate_member_role
@@ -94,16 +93,6 @@ class MemberTest < ActiveSupport::TestCase
     assert !member.save
   end
 
-  def test_set_issue_category_nil_should_handle_nil_values
-    m = Member.new
-    assert_nil m.user
-    assert_nil m.project
-
-    assert_nothing_raised do
-      m.set_issue_category_nil
-    end
-  end
-
   def test_destroy
     category1 = IssueCategory.find(1)
     assert_equal @jsmith.user.id, category1.assigned_to_id
@@ -131,17 +120,7 @@ class MemberTest < ActiveSupport::TestCase
     end
     assert m.destroyed?
   ensure
-    Member._destroy_callbacks.reject! {|c| c.filter==:destroy_test_callback}
-  end
-
-  def test_roles_should_be_unique
-    m = Member.new(:user_id => 1, :project_id => 1)
-    m.member_roles.build(:role_id => 1)
-    m.member_roles.build(:role_id => 1)
-    m.save!
-    m.reload
-    assert_equal 1, m.roles.count
-    assert_equal [1], m.roles.map(&:id)
+    Member._destroy_callbacks.delete(:destroy_test_callback)
   end
 
   def test_sort_without_roles
