@@ -202,13 +202,7 @@ class RepositorySubversionTest < ActiveSupport::TestCase
 
     def test_log_encoding_ignore_setting
       with_settings :commit_logs_encoding => 'windows-1252' do
-        s1 = "\xC2\x80"
-        s2 = "\xc3\x82\xc2\x80"
-        if s1.respond_to?(:force_encoding)
-          s1.force_encoding('ISO-8859-1')
-          s2.force_encoding('UTF-8')
-          assert_equal s1.encode('UTF-8'), s2
-        end
+        s2 = "\xc3\x82\xc2\x80".force_encoding('UTF-8')
         c = Changeset.new(:repository => @repository,
                           :comments   => s2,
                           :revision   => '123',
